@@ -298,4 +298,4 @@ def css_minify(css, settings: dict):
     css = add_encoding(css) if settings.get("prefix", False) else css
     css = restore_needed_space(css)
     css = add_timestamp(css) if settings.get("timestamp", False) else css
-    return css.strip()
+    return css.strip(), None
