@@ -13,4 +13,4 @@ def jinja_minify(jinja, settings: dict):
         jinja_env.parse(jinja)
     except Exception as e:
         logger.error("Jinja validator: {e}")
-    return jinja.strip()
+    return jinja.strip(), None
